==> moyoung_ble_plugin-1.0.57.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/WeatherChangeHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.listener.CRPWeatherChangeListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.FileTransBean;
import com.moyoung.moyoung_ble_plugin.model.WeatherChangeBean;

import io.flutter.plugin.common.MethodCall;

public class WeatherChangeHandler extends BaseConnectionEventChannelHandler {
    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setWeatherChangeListener(new CRPWeatherChangeListener() {
            @Override
            public void onUpdateWeather() {
                if (eventSink == null) {
                    return;
                }
                WeatherChangeBean bean = new WeatherChangeBean();
                bean.setType(WeatherChangeBean.UPDATE_WEATHER);
                String jsonStr = GsonUtils.get().toJson(bean, WeatherChangeBean.class);
                activity.runOnUiThread(() -> eventSink.success(jsonStr));
            }

            @Override
            public void onTempUnitChange(int tempUnit) {
                if (eventSink == null) {
                    return;
                }
                WeatherChangeBean bean = new WeatherChangeBean();
                bean.setType(WeatherChangeBean.TEMP_UNIT_CHANGE);
                bean.setTempUnit(tempUnit);
                String jsonStr = GsonUtils.get().toJson(bean, WeatherChangeBean.class);
                activity.runOnUiThread(() -> eventSink.success(jsonStr));
            }
        });
    }

}

==> moyoung_ble_plugin-1.0.62.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/WeatherChangeHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.listener.CRPWeatherChangeListener;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.FileTransBean;
import com.moyoung.moyoung_ble_plugin.model.WeatherChangeBean;

import io.flutter.plugin.common.MethodCall;

public class WeatherChangeHandler extends BaseConnectionEventChannelHandler {
    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setWeatherChangeListener(new CRPWeatherChangeListener() {
            @Override
            public void onUpdateWeather() {
                if (eventSink == null) {
                    return;
                }
                WeatherChangeBean bean = new WeatherChangeBean();
                bean.setType(WeatherChangeBean.UPDATE_WEATHER);
                String jsonStr = GsonUtils.get().toJson(bean, WeatherChangeBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(jsonStr));
            }

            @Override
            public void onTempUnitChange(int tempUnit) {
                if (eventSink == null) {
                    return;
                }
                WeatherChangeBean bean = new WeatherChangeBean();
                bean.setType(WeatherChangeBean.TEMP_UNIT_CHANGE);
                bean.setTempUnit(tempUnit);
                String jsonStr = GsonUtils.get().toJson(bean, WeatherChangeBean.class);
                new Handler(Looper.getMainLooper()).post(() -> eventSink.success(jsonStr));
            }
        });
    }

}
